@@ -10,8 +10,9 @@ thin.prob <- function( region
                        ){
 
   ## Intercept, V, ....
-    AgeTo5[AgeTo5 > -1] <- -1
-pars <- c(-6.3897, 0.5699, -0.038, -0.0693, 0.8227, 1.1354, -21.71, -0.0955, -0.0012)
+  AgeTo5[AgeTo5 > -1] <- -1
+  pars <- c(-6.3897, 0.5699, -0.038, -0.0693, 0.8227, 1.1354, -21.71,
+            -0.0955, -0.0012)
   return(1 / (1 + exp(- (
       pars[1]  + 
       pars[2]  * log(vuprha.m3.ha) +
